==> ejc-settlementmanage-impl-3.0.0-20221202.092227-124-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementBookOtherDetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工程分包结算书子表-支出明细-其它
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_settlement_book_other")
public class SettlementBookOtherDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    @TableField(value="deductions_name")
    private java.lang.String deductionsName; // 扣款名称
    @TableField(value="units")
    private java.lang.String unitsC; // 单位
    @TableField(value="number")
    private java.math.BigDecimal number; // 数量
    @TableField(value="extax_unitprice")
    private java.math.BigDecimal extaxUnitpriceC; // 除税单价
    @TableField(value="intax_unitprice")
    private java.math.BigDecimal intaxUnitprice; // 含税单价
    @TableField(value="extax_price")
    private java.math.BigDecimal extaxPriceC; // 除税金额
    @TableField(value="intax_price")
    private java.math.BigDecimal intaxPrice; // 含税金额
    @TableField(value="remarks")
    private java.lang.String remarksC; // 单位
    @TableField(value="withholding_other")
    private java.lang.String withholdingOther; // 扣款类型
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 扣款名称
     */
    public java.lang.String getDeductionsName() {
        return deductionsName;
    }

    /**
     * 扣款名称
     */
    public void setDeductionsName(java.lang.String deductionsName) {
        this.deductionsName = deductionsName;
    }

    /**
     * 数量
     */
    public java.math.BigDecimal getNumber() {
        return number;
    }

    /**
     * 数量
     */
    public void setNumber(java.math.BigDecimal number) {
        this.number = number;
    }
      /**
     * 含税单价
     */
    public java.math.BigDecimal getIntaxUnitprice() {
        return intaxUnitprice;
    }

    /**
     * 含税单价
     */
    public void setIntaxUnitprice(java.math.BigDecimal intaxUnitprice) {
        this.intaxUnitprice = intaxUnitprice;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getIntaxPrice() {
        return intaxPrice;
    }

    /**
     * 含税金额
     */
    public void setIntaxPrice(java.math.BigDecimal intaxPrice) {
        this.intaxPrice = intaxPrice;
    }

    public String getWithholdingOther() {
        return withholdingOther;
    }

    public void setWithholdingOther(String withholdingOther) {
        this.withholdingOther = withholdingOther;
    }

    public String getUnitsC() {
        return unitsC;
    }

    public void setUnitsC(String unitsC) {
        this.unitsC = unitsC;
    }

    public BigDecimal getExtaxUnitpriceC() {
        return extaxUnitpriceC;
    }

    public void setExtaxUnitpriceC(BigDecimal extaxUnitpriceC) {
        this.extaxUnitpriceC = extaxUnitpriceC;
    }

    public BigDecimal getExtaxPriceC() {
        return extaxPriceC;
    }

    public void setExtaxPriceC(BigDecimal extaxPriceC) {
        this.extaxPriceC = extaxPriceC;
    }

    public String getRemarksC() {
        return remarksC;
    }

    public void setRemarksC(String remarksC) {
        this.remarksC = remarksC;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20221210.112757-136-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementBookOtherDetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工程分包结算书子表-支出明细-其它
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_settlement_book_other")
public class SettlementBookOtherDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    @TableField(value="deductions_name")
    private java.lang.String deductionsName; // 扣款名称
    @TableField(value="units")
    private java.lang.String unitsC; // 单位
    @TableField(value="number")
    private java.math.BigDecimal number; // 数量
    @TableField(value="extax_unitprice")
    private java.math.BigDecimal extaxUnitpriceC; // 除税单价
    @TableField(value="intax_unitprice")
    private java.math.BigDecimal intaxUnitpriceC; // 含税单价
    @TableField(value="extax_price")
    private java.math.BigDecimal extaxPriceC; // 除税金额
    @TableField(value="intax_price")
    private java.math.BigDecimal intaxPriceC; // 含税金额
    @TableField(value="remarks")
    private java.lang.String remarksC; // 单位
    @TableField(value="withholding_other")
    private java.lang.String withholdingOther; // 扣款类型
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 扣款名称
     */
    public java.lang.String getDeductionsName() {
        return deductionsName;
    }

    /**
     * 扣款名称
     */
    public void setDeductionsName(java.lang.String deductionsName) {
        this.deductionsName = deductionsName;
    }

    /**
     * 数量
     */
    public java.math.BigDecimal getNumber() {
        return number;
    }

    /**
     * 数量
     */
    public void setNumber(java.math.BigDecimal number) {
        this.number = number;
    }


    public BigDecimal getIntaxUnitpriceC() {
        return intaxUnitpriceC;
    }

    public void setIntaxUnitpriceC(BigDecimal intaxUnitpriceC) {
        this.intaxUnitpriceC = intaxUnitpriceC;
    }

    public BigDecimal getIntaxPriceC() {
        return intaxPriceC;
    }

    public void setIntaxPriceC(BigDecimal intaxPriceC) {
        this.intaxPriceC = intaxPriceC;
    }

    public String getWithholdingOther() {
        return withholdingOther;
    }

    public void setWithholdingOther(String withholdingOther) {
        this.withholdingOther = withholdingOther;
    }

    public String getUnitsC() {
        return unitsC;
    }

    public void setUnitsC(String unitsC) {
        this.unitsC = unitsC;
    }

    public BigDecimal getExtaxUnitpriceC() {
        return extaxUnitpriceC;
    }

    public void setExtaxUnitpriceC(BigDecimal extaxUnitpriceC) {
        this.extaxUnitpriceC = extaxUnitpriceC;
    }

    public BigDecimal getExtaxPriceC() {
        return extaxPriceC;
    }

    public void setExtaxPriceC(BigDecimal extaxPriceC) {
        this.extaxPriceC = extaxPriceC;
    }

    public String getRemarksC() {
        return remarksC;
    }

    public void setRemarksC(String remarksC) {
        this.remarksC = remarksC;
    }
}
